==> pegasus-support-1.6.3-sources.jar: com/thebeastshop/support/vo/member/MemberAddressDTO.java <==
package com.thebeastshop.support.vo.member;

import java.io.Serializable;

public class MemberAddressDTO implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private String receiverName;
	private String receiverPhone;
	private Boolean asDefault;
	private String location;
	private String zipCode;
	private Long districtId;
	private Long ringId;

	public String getReceiverName() {
		return receiverName;
	}

	public void setReceiverName(String receiverName) {
		this.receiverName = receiverName;
	}

	public String getReceiverPhone() {
		return receiverPhone;
	}

	public void setReceiverPhone(String receiverPhone) {
		this.receiverPhone = receiverPhone;
	}

	public Boolean getAsDefault() {
		return asDefault;
	}

	public void setAsDefault(Boolean asDefault) {
		this.asDefault = asDefault;
	}

	public String getLocation() {
		return location;
	}

	public void setLocation(String location) {
		this.location = location;
	}

	public String getZipCode() {
		return zipCode;
	}

	public void setZipCode(String zipCode) {
		this.zipCode = zipCode;
	}

	public Long getDistrictId() {
		return districtId;
	}

	public void setDistrictId(Long districtId) {
		this.districtId = districtId;
	}

	public Long getRingId() {
		return ringId;
	}

	public void setRingId(Long ringId) {
		this.ringId = ringId;
	}

	@Override
	public String toString() {
		return "MemberAddressDTO [receiverName=" + receiverName + ", receiverPhone=" + receiverPhone + ", asDefault="
				+ asDefault + ", location=" + location + ", zipCode=" + zipCode + ", districtId=" + districtId
				+ ", ringId=" + ringId + "]";
	}

}

==> pegasus-support-2.2.7-sources.jar: com/thebeastshop/support/vo/member/MemberAddressDTO.java <==
package com.thebeastshop.support.vo.member;

import java.io.Serializable;

public class MemberAddressDTO implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private String receiverName;
	private String receiverPhone;
	private Boolean asDefault;
	private String location;
	private String zipCode;
	private Long districtId;
	private Long ringId;
	private String ringName;

	public String getReceiverName() {
		return receiverName;
	}

	public void setReceiverName(String receiverName) {
		this.receiverName = receiverName;
	}

	public String getReceiverPhone() {
		return receiverPhone;
	}

	public void setReceiverPhone(String receiverPhone) {
		this.receiverPhone = receiverPhone;
	}

	public Boolean getAsDefault() {
		return asDefault;
	}

	public void setAsDefault(Boolean asDefault) {
		this.asDefault = asDefault;
	}

	public String getLocation() {
		return location;
	}

	public void setLocation(String location) {
		this.location = location;
	}

	public String getZipCode() {
		return zipCode;
	}

	public void setZipCode(String zipCode) {
		this.zipCode = zipCode;
	}

	public Long getDistrictId() {
		return districtId;
	}

	public void setDistrictId(Long districtId) {
		this.districtId = districtId;
	}

	public Long getRingId() {
		return ringId;
	}

	public void setRingId(Long ringId) {
		this.ringId = ringId;
	}

	public String getRingName() {
		return ringName;
	}

	public void setRingName(String ringName) {
		this.ringName = ringName;
	}

	@Override
	public String toString() {
		return "MemberAddressDTO [receiverName=" + receiverName + ", receiverPhone=" + receiverPhone + ", asDefault="
				+ asDefault + ", location=" + location + ", zipCode=" + zipCode + ", districtId=" + districtId
				+ ", ringId=" + ringId + "]";
	}

}
